searchData={"items":[{"type":"module","title":"OpentelemetrySqlcommenter","doc":"Adds OpenTelemetry trace context to SQL queries as comments.\n\nOpentelemetrySqlcommenter is an Elixir library that automatically adds\nOpenTelemetry trace context to your SQL queries as comments. This enables\nbetter observability by linking database operations with distributed\ntraces.\n\n> **Note:** Currently only compatible with PostgreSQL databases.","ref":"OpentelemetrySqlcommenter.html"},{"type":"module","title":"Features - OpentelemetrySqlcommenter","doc":"- Automatically injects OpenTelemetry trace context into SQL queries\n- Compatible with Ecto repositories using PostgreSQL\n- Follows W3C Trace Context specification\n- Minimal performance overhead\n- Easy integration with existing projects","ref":"OpentelemetrySqlcommenter.html#module-features"},{"type":"module","title":"Installation - OpentelemetrySqlcommenter","doc":"Add `opentelemetry_sqlcommenter` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry_sqlcommenter, \"~> 0.1.1\"},\n  ]\nend\n```","ref":"OpentelemetrySqlcommenter.html#module-installation"},{"type":"module","title":"Usage - OpentelemetrySqlcommenter","doc":"1. In your Ecto repository, delegate the `prepare_query` function to OpentelemetrySqlcommenter:\n\n```elixir\ndefmodule YourApp.Repo do\n  use Ecto.Repo,\n    otp_app: :your_app,\n    adapter: Ecto.Adapters.Postgres\n\n  defdelegate prepare_query(operation, query, opts), to: OpentelemetrySqlcommenter\nend\n```\n\n2. That's it! Your SQL queries will now include trace context as comments:\n\n```\nSELECT u1.\"id\", u1.\"email\" FROM \"user_token\"\nAS u0 INNER JOIN \"user\" AS u1 ON u1.\"id\" = u0.\"user_id\"\nWHERE ((u0.\"token\" = $1) AND (u0.\"context\" = $2)) AND\n(u0.\"inserted_at\" > $3::timestamp + (-(60)::numeric * interval '1 day'))\n/*traceparent='00-6b6bcfabaea5ef9890481e9b0c18efac-4deda0f3c249b6c7-01'*/\n```","ref":"OpentelemetrySqlcommenter.html#module-usage"},{"type":"module","title":"Configuration - OpentelemetrySqlcommenter","doc":"No additional configuration is needed if you already have OpenTelemetry set up in your application.","ref":"OpentelemetrySqlcommenter.html#module-configuration"},{"type":"module","title":"How It Works - OpentelemetrySqlcommenter","doc":"The library:\n1. Intercepts queries before they're sent to the database\n2. Checks for active OpenTelemetry trace context\n3. If present, adds the trace context as a SQL comment\n4. Preserves all existing query options","ref":"OpentelemetrySqlcommenter.html#module-how-it-works"},{"type":"module","title":"Important Disclaimer - OpentelemetrySqlcommenter","doc":"⚠️ **Impact on Query Performance**\n\nThis library disables prepared statements and query caching by setting\n`prepare: :unnamed` for all queries. This is necessary because:\n\n1. SQL comments make each query unique, even if the underlying SQL is identical\n2. Prepared statements and caching rely on query text matching exactly\n3. Adding trace context makes each query instance unique,\ndefeating the purpose of preparation and caching","ref":"OpentelemetrySqlcommenter.html#module-important-disclaimer"},{"type":"module","title":"Performance Implications - OpentelemetrySqlcommenter","doc":"- **Prepared Statements**: Normally, Postgres can prepare and cache\nquery execution plans. With this library, each query is treated as new,\nrequiring a new execution plan.","ref":"OpentelemetrySqlcommenter.html#module-performance-implications"},{"type":"module","title":"When to Use - OpentelemetrySqlcommenter","doc":"Use this library when:\n- Trace context in SQL logs is more important than maximum query performance\n- You're debugging or need detailed observability\n- Your application's performance isn't critically dependent on prepared statements\n\nConsider disabling it in performance-critical environments or creating a configuration option to toggle it based on your needs.","ref":"OpentelemetrySqlcommenter.html#module-when-to-use"},{"type":"module","title":"Alternative Approaches - OpentelemetrySqlcommenter","doc":"If you need both tracing and prepared statements, consider:\n1. Using separate logging mechanisms for trace context\n2. Implementing selective tracing for specific queries only\n3. Using database-specific audit logging features","ref":"OpentelemetrySqlcommenter.html#module-alternative-approaches"},{"type":"module","title":"Related Links - OpentelemetrySqlcommenter","doc":"- [SQL Commenter with Postgrex](https://dev.to/dkuku/sql-commenter-with-postgrex-2bfd)\n- [OpenTelemetry Documentation](https://opentelemetry.io/docs/)\n- [W3C Trace Context Specification](https://www.w3.org/TR/trace-context/)\n\nAdds OpenTelemetry trace context to SQL queries as comments.\n\nThis module is designed to be used with Ecto repositories to automatically inject\nOpenTelemetry trace information into SQL queries. It adds a SQL comment containing\nthe W3C trace context (traceparent) to each query, enabling correlation between\ndatabase operations and distributed traces.","ref":"OpentelemetrySqlcommenter.html#module-related-links"},{"type":"module","title":"Usage - OpentelemetrySqlcommenter","doc":"In your Ecto repository, add:\n\n    defmodule YourApp.Repo do\n      use Ecto.Repo,\n        otp_app: :your_app,\n        adapter: Ecto.Adapters.Postgres\n\n      defdelegate prepare_query(operation, query, opts), to: OpentelemetrySqlcommenter\n    end","ref":"OpentelemetrySqlcommenter.html#module-usage"},{"type":"module","title":"Format - OpentelemetrySqlcommenter","doc":"The module adds SQL comments in the following format:\n\n```\nYOUR QUERY/*traceparent='00-trace_id-span_id-flags'*/\n```","ref":"OpentelemetrySqlcommenter.html#module-format"},{"type":"function","title":"OpentelemetrySqlcommenter.prepare_query/3","doc":"Prepares a query by adding OpenTelemetry trace context as a SQL comment for any active span.\n\nSimilar to `prepare_query_sampled/3` but adds trace context for all traces regardless of sampling status.\nDesigned to be used with `defdelegate` in your Ecto repository when you want to track all queries.","ref":"OpentelemetrySqlcommenter.html#prepare_query/3"},{"type":"function","title":"Setup - OpentelemetrySqlcommenter.prepare_query/3","doc":"defmodule MyApp.Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.Postgres\n\n      defdelegate prepare_query(operation, query, opts), to: OpentelemetrySqlcommenter\n    end","ref":"OpentelemetrySqlcommenter.html#prepare_query/3-setup"},{"type":"function","title":"Parameters - OpentelemetrySqlcommenter.prepare_query/3","doc":"* `_operation` - The type of operation (unused, maintained for Ecto compatibility)\n  * `query` - The SQL query string\n  * `opts` - Query options keyword list","ref":"OpentelemetrySqlcommenter.html#prepare_query/3-parameters"},{"type":"function","title":"Returns - OpentelemetrySqlcommenter.prepare_query/3","doc":"* `{modified_query, modified_opts}` - Tuple containing the query and modified options with trace context\n  * `{query, opts}` - Original query and options if no active sampled trace is present\n\nNote: This function disables prepared statements by setting `prepare: :unnamed` when adding trace context.","ref":"OpentelemetrySqlcommenter.html#prepare_query/3-returns"},{"type":"function","title":"OpentelemetrySqlcommenter.prepare_query_sampled/3","doc":"Prepares a query by adding OpenTelemetry trace context as a SQL comment, but only for sampled traces.\n\nThis function is designed to be used with `defdelegate` in your Ecto repository to automatically\nadd trace context to all database queries when sampling is enabled (trace_flags = 1).","ref":"OpentelemetrySqlcommenter.html#prepare_query_sampled/3"},{"type":"function","title":"Setup - OpentelemetrySqlcommenter.prepare_query_sampled/3","doc":"defmodule MyApp.Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.Postgres\n\n      defdelegate prepare_query(operation, query, opts), to: OpentelemetrySqlcommenter, as: :prepare_query_sampled\n    end","ref":"OpentelemetrySqlcommenter.html#prepare_query_sampled/3-setup"},{"type":"function","title":"Parameters - OpentelemetrySqlcommenter.prepare_query_sampled/3","doc":"* `_operation` - The type of operation (unused, maintained for Ecto compatibility)\n  * `query` - The SQL query string\n  * `opts` - Query options keyword list","ref":"OpentelemetrySqlcommenter.html#prepare_query_sampled/3-parameters"},{"type":"function","title":"Returns - OpentelemetrySqlcommenter.prepare_query_sampled/3","doc":"* `{modified_query, modified_opts}` - Tuple containing the query and modified options with trace context\n  * `{query, opts}` - Original query and options if no active trace is present\n\nNote: This function disables prepared statements by setting `prepare: :unnamed` when adding trace context.","ref":"OpentelemetrySqlcommenter.html#prepare_query_sampled/3-returns"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}